@@ -12,6 +12,7 @@ from aasm.intermediate.argument import (
     ConnectionList,
     EnumValue,
     Float,
+    FloatList,
     MessageList,
     ReceivedMessageParam,
     SendMessageParam,
@@ -171,15 +172,17 @@ class PythonSpadeCode(PythonCode):
 
     def add_agent_constructor(self, agent: Agent) -> None:
         self.add_line(
-            "def __init__(self, jid, password, backup_url = None, backup_period = 60, backup_delay = 0, logger = None, **kwargs):"
+            "def __init__(self, jid, password, backup_method = None, backup_queue = None, backup_url = None, backup_period = 60, backup_delay = 0, logger = None, **kwargs):"
         )
         self.indent_right()
 
         self.add_line("super().__init__(jid, password, verify_security=False)")
         self.add_line(
-            "if logger: logger.debug(f'[{jid}] Received parameters: jid: {jid}, password: {password}, backup_url: {backup_url}, backup_period: {backup_period}, backup_delay: {backup_delay}, kwargs: {kwargs}')"
+            "if logger: logger.debug(f'[{jid}] Received parameters: jid: {jid}, password: {password}, backup_method: {backup_method}, backup_queue: {backup_queue}, backup_url: {backup_url}, backup_period: {backup_period}, backup_delay: {backup_delay}, kwargs: {kwargs}')"
         )
         self.add_line("self.logger = logger")
+        self.add_line("self.backup_method = backup_method")
+        self.add_line("self.backup_queue = backup_queue")
         self.add_line("self.backup_url = backup_url")
         self.add_line("self.backup_period = backup_period")
         self.add_line("self.backup_delay = backup_delay")
@@ -286,7 +289,7 @@ class PythonSpadeCode(PythonCode):
         self.add_line("def setup(self):")
         self.indent_right()
 
-        self.add_line("if self.backup_url:")
+        self.add_line("if self.backup_method is not None:")
         self.indent_right()
         self.add_no_match_template("BackupBehaviour")
         self.add_line(
@@ -402,11 +405,13 @@ class PythonSpadeCode(PythonCode):
             )
         self.indent_left()
         self.add_line("},")
-
         self.indent_left()
         self.add_line("}")
+
+        self.add_line("if self.agent.backup_method == 'http':")
+        self.indent_right()
         self.add_line(
-            "if self.agent.logger: self.agent.logger.debug(f'[{self.agent.jid}] Sending backup data: {data}')"
+            "if self.agent.logger: self.agent.logger.debug(f'[{self.agent.jid}] Sending backup data with http: {data}')"
         )
         self.add_line("try:")
         self.indent_right()
@@ -421,6 +426,29 @@ class PythonSpadeCode(PythonCode):
         )
         self.indent_left()
         self.indent_left()
+        self.add_line("elif self.agent.backup_method == 'queue':")
+        self.indent_right()
+        self.add_line(
+            "if self.agent.logger: self.agent.logger.debug(f'[{self.agent.jid}] Sending backup data with queue: {data}')"
+        )
+        self.add_line("try:")
+        self.indent_right()
+        self.add_line("await self.agent.backup_queue.coro_put(data)")
+        self.indent_left()
+        self.add_line("except Exception as e:")
+        self.indent_right()
+        self.add_line(
+            "if self.agent.logger: self.agent.logger.error(f'[{self.agent.jid}] Backup error type: {e.__class__}, additional info: {e}')"
+        )
+        self.indent_left()
+        self.indent_left()
+        self.add_line("else:")
+        self.indent_right()
+        self.add_line(
+            "if self.agent.logger: self.agent.logger.warning(f'[{self.agent.jid}] Unknown backup method: {self.agent.backup_method}')"
+        )
+        self.indent_left()
+        self.indent_left()
         self.indent_left()
 
     def add_agent_behaviour(self, behaviour: Behaviour, behaviour_type: str) -> None:
@@ -507,6 +535,8 @@ class PythonSpadeCode(PythonCode):
         send_msg = f'send = {{ "type": "{message.type}", "performative": "{message.performative}", '
         for float_param_name in message.float_params:
             send_msg += f'"{float_param_name}": 0.0, '
+        for connection_param_name in message.connection_params:
+            send_msg += f'"{connection_param_name}": "", '
         send_msg += "}"
         self.add_line(send_msg)
 
@@ -914,6 +944,11 @@ class PythonSpadeCode(PythonCode):
                     dst = self.parse_arg(statement.dst)
                     list_ = self.parse_arg(statement.list_)
                     idx = f"int(self.agent.limit_number(round(self.agent.limit_number({self.parse_arg(statement.idx)}))))"
+                    match statement.list_.type_in_op:
+                        case FloatList():
+                            value = f"self.agent.limit_number({list_}[{idx}])"
+                        case _:
+                            value = f"{list_}[{idx}]"
                     list_len = f"int(self.agent.limit_number(len({list_})))"
                     self.add_line(f"if {idx} < 0 or {idx} >= {list_len}:")
                     self.indent_right()
@@ -922,16 +957,19 @@ class PythonSpadeCode(PythonCode):
                     )
                     self.add_line("return")
                     self.indent_left()
-                    self.add_line(f"{dst} = self.agent.limit_number({list_}[{idx}])")
+                    self.add_line(f"{dst} = {value}")
 
                 case ListWrite():
                     self.add_line("")
                     self.add_line("# list write")
                     list_ = self.parse_arg(statement.list_)
                     idx = f"int(self.agent.limit_number(round(self.agent.limit_number({self.parse_arg(statement.idx)}))))"
-                    value = (
-                        f"self.agent.limit_number({self.parse_arg(statement.value)})"
-                    )
+                    match statement.value.type_in_op:
+                        case Float():
+                            value = f"self.agent.limit_number({self.parse_arg(statement.value)})"
+                        case _:
+                            value = self.parse_arg(statement.value)
+                    dst = f"{list_}[{idx}]"
                     list_len = f"int(self.agent.limit_number(len({list_})))"
                     self.add_line(f"if {idx} < 0 or {idx} >= {list_len}:")
                     self.indent_right()
@@ -940,7 +978,7 @@ class PythonSpadeCode(PythonCode):
                     )
                     self.add_line("return")
                     self.indent_left()
-                    self.add_line(f"{list_}[{idx}] = {value}")
+                    self.add_line(f"{dst} = {value}")
 
                 case TrigonometryOperation():
                     dst = self.parse_arg(statement.dst)
